@@ -10,10 +10,7 @@ or
     <name>_tree.json
     <name>_meta.json
 
-The viewer runs inside a container, which requires Docker.  Run `nextstrain
-check-setup` to check if Docker is installed and works.
-
-¹ <https://nextstrain.github.io/auspice/introduction/how-to-run#input-file-formats>
+¹ <https://docs.nextstrain.org/projects/auspice/en/latest/introduction/how-to-run.html#input-file-formats>
 """
 
 import re
