@@ -11,7 +11,7 @@ from sys import stdin
 from textwrap import dedent
 from typing import Iterable, List
 from .. import runner, hostenv, config
-from ..types import RunnerTestResults
+from ..types import RunnerTestResults, RunnerTestResultStatus
 from ..util import warn, colored, capture_output, exec_or_return, resolve_path, split_image_name
 from ..volume import store_volume
 from ..__version__ import __version__
@@ -135,7 +135,7 @@ def test_setup() -> RunnerTestResults:
         desired = 2 * GiB
 
         msg = 'containers have access to >%.0f GiB of memory' % (desired / GiB)
-        status = ...
+        status: RunnerTestResultStatus = ...
 
         if image_exists():
             report_memory = """
@@ -169,7 +169,7 @@ def test_setup() -> RunnerTestResults:
         minimum_tag = "build-20190119T045444Z"
 
         msg = 'image is new enough for this CLI version'
-        status = ...
+        status: RunnerTestResultStatus = ...
 
         repository, tag = split_image_name(DEFAULT_IMAGE)
 
@@ -279,19 +279,24 @@ def latest_build_image(image_name: str) -> str:
     presumption that it points to some other mutable snapshot that should be
     pulled in-place to update.
     """
+    def GET(url, **kwargs):
+        response = requests.get(url, **kwargs)
+        response.raise_for_status()
+        return response
+
     def auth_token(repository: str) -> str:
         url, params = "https://auth.docker.io/token", {
             "scope": "repository:%s:pull" % repository,
             "service": "registry.docker.io",
         }
-        return requests.get(url, params = params).json().get("token")
+        return GET(url, params = params).json().get("token")
 
     def tags(respository: str) -> List[str]:
         url, headers = "https://registry.hub.docker.com/v2/%s/tags/list" % repository, {
             "Accept": "application/vnd.docker.distribution.manifest.v2+json",
             "Authorization": "Bearer %s" % auth_token(repository),
         }
-        return requests.get(url, headers = headers).json().get("tags", [])
+        return GET(url, headers = headers).json().get("tags", [])
 
     repository, tag = split_image_name(image_name)
 
